@@ -1,43 +1,88 @@
 <?php
-#BEGIN_LICENSE
 #-------------------------------------------------------------------------------
 #
 # Module : AdvancedContent (c) 2010 by Georg Busch (georg.busch@gmx.net)
-# Version: 0.3.4
+#          a content management tool for CMS Made Simple
+#          The projects homepage is dev.cmsmadesimple.org/projects/content2/
+#          CMS Made Simple is (c) 2004-2010 by Ted Kulp
+#          The projects homepage is: cmsmadesimple.org
+# Version: 0.5
 # File   : action.defaultadmin.php
+# Purpose: performs the default backend action if "Extensions->AdvancedContent"
+#          is selected
+# License: GPL
 #
 #-------------------------------------------------------------------------------
-#
-# CMS - CMS Made Simple is (c) 2004-2010 by Ted Kulp (wishy@cmsmadesimple.org)
-# This project's homepage is: http://www.cmsmadesimple.org
-#
-#-------------------------------------------------------------------------------
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
-#
-#-------------------------------------------------------------------------------
-#END_LICENSE
 
 if(!isset($gCms)) exit;
 
+if(isset($params['importpages'])) {
+	// Set to content2
+	$query    = "UPDATE ".cms_db_prefix()."content SET type = ? WHERE type = ?";
+	$dbresult = $db->Execute($query, array('content2','content'));
+	$params['message'] = 'pagesimported';
+	$params['submit'] = true;
+}
+
 $this->smarty->assign('startform', $this->CreateFormStart($id, 
 	'savePrefs', $returnid,'post','multipart/form-data'));
 
 $this->smarty->assign('endform', $this->CreateFormEnd());
 $this->smarty->assign('uninstallaction_text', $this->lang('uninstallaction'));
 
+// Module settings
+
+// ToDo: ajax stuff
+$this->smarty->assign('importpages_input', 
+	$this->CreateLink($id, 'defaultadmin', '', $gCms->variables['admintheme']->DisplayImage('icons/system/import.gif', '','','','systemicon') . '&nbsp;' . $this->lang('importpages'), 
+		array('importpages'=>true), $this->lang('confirmimport')));
+//---
+
+$actions = array(lang('none')=>'', 
+	$this->lang('setcontent1')=>2, 
+	$this->lang('setcontent2')=>3,
+	$this->lang('deletepages')=>1);
+
+$this->smarty->assign('uninstallaction_input', 
+	$this->CreateInputDropdown($id, 'uninstall_action', $actions, '', 
+		$this->GetPreference('uninstall_action')));
+
+$this->smarty->assign('uploadsdir_text', $this->lang('useimguploadsdir'));
+$this->smarty->assign('uploadsdir_input', 
+	$this->CreateInputHidden($id,'useimguploadsdir',0) .
+	$this->CreateInputCheckbox($id, 'useimguploadsdir', '1', 
+		$this->GetPreference('useimguploadsdir',0), 'class="pagecheckbox"'));
+
+// FilePicker settings
+
+$this->smarty->assign('filepickersettings_text', $this->lang('filepickersettings'));
+
+$this->smarty->assign('filepickersize_text', $this->lang('filepickersize'));
+
+$this->smarty->assign('filepickerwidth_input', 
+	$this->CreateInputText($id, 'filepickerwidth', 
+		$this->GetPreference('filepickerwidth'), 5, 4));
+
+$this->smarty->assign('filepickerheight_input', 
+	$this->CreateInputText($id, 'filepickerheight', 
+		$this->GetPreference('filepickerheight',''), 5, 4));
+
+$this->smarty->assign('filepickerheightunit_input', 
+	$this->CreateInputDropdown($id,'filepickerheightunit',array('px'=>'px','%'=>'%','em'=>'em'),0,
+		$this->GetPreference('filepickerheightunit','px')));
+
+$this->smarty->assign('filepickerwidthunit_input', 
+	$this->CreateInputDropdown($id,'filepickerwidthunit',array('px'=>'px','%'=>'%','em'=>'em'),0,
+		$this->GetPreference('filepickerwidthunit','px')));
+
+$this->smarty->assign('filepickerstyle_text', $this->lang('filepickerstyle'));
+$filepickerstyles = array($this->Lang("filenameonly")=>"filename",
+	$this->Lang('thumbnailsonly')=>'thumbnails',
+	$this->Lang('filenameandthumbnails')=>'both');
+$this->smarty->assign('filepickerstyle_input', 
+	$this->CreateInputDropdown($id,'filepickerstyle',$filepickerstyles,0,
+		$this->GetPreference('filepickerstyle')));
+
 $this->smarty->assign('restrictdirs_text', $this->lang('restrictdirs'));
 $this->smarty->assign('restrictdirs_input', 
 	$this->CreateInputHidden($id,'restrictdirs',0) . 
@@ -64,13 +109,17 @@ $this->smarty->assign('allowscaling_input',
 	$this->CreateInputCheckbox($id, 'allowscaling', '1', 
 		$this->GetPreference('allowscaling'), 'class="pagecheckbox"'));
 
-$this->smarty->assign('filepickerstyle_text', $this->lang('filepickerstyle'));
-$filepickerstyles = array($this->Lang("filenameonly")=>"filename",
-	$this->Lang('thumbnailsonly')=>'thumbnails',
-	$this->Lang('filenameandthumbnails')=>'both');
-$this->smarty->assign('filepickerstyle_input', 
-	$this->CreateInputDropdown($id,'filepickerstyle',$filepickerstyles,0,
-		$this->GetPreference('filepickerstyle')));
+$this->smarty->assign('defaultdimensions_text', $this->lang('defaultdimensions'));
+
+$this->smarty->assign('scalingwidth_text', $this->lang('scalingwidth'));
+$this->smarty->assign('scalingwidth_input', 
+	$this->CreateInputText($id, 'scalingwidth', 
+		$this->GetPreference('scalingwidth'), 5, 4));
+
+$this->smarty->assign('scalingheight_text', $this->lang('scalingheight'));
+$this->smarty->assign('scalingheight_input', 
+	$this->CreateInputText($id, 'scalingheight', 
+		$this->GetPreference('scalingheight'), 5, 4));
 
 $this->smarty->assign('allowupscaling_text', $this->lang('allowupscaling'));
 $this->smarty->assign('allowupscaling_input', 
@@ -84,50 +133,64 @@ $this->smarty->assign('makethumbnail_input',
 	$this->CreateInputCheckbox($id, 'makethumbnail', '1', 
 		$this->GetPreference('makethumbnail'), 'class="pagecheckbox"'));
 
-$this->smarty->assign('defaultdimensions_text', $this->lang('defaultdimensions'));
-$this->smarty->assign('filepickersettings_text', $this->lang('filepickersettings'));
+$filePicker =& $this->GetFilePicker();
+$fileType = strtolower($filePicker->GetFileType('../modules/AdvancedContent/images/sort.png',true));
+$this->smarty->assign('usemimetype_text', $this->lang('usemimetype'));
+$this->smarty->assign('usemimetype_input', 
+	$this->CreateInputHidden($id,'usemimetype',0) .
+	$this->CreateInputCheckbox($id, 'usemimetype', '1', 
+		($fileType != 'image/png'?$this->SetPreference('usemimetype',0):$this->GetPreference('usemimetype')), 'class="pagecheckbox"'.($fileType != 'image/png'?' disabled="disabled"':'')) . 
+	($fileType == 'image/png'?'':$this->lang('nomimetype')));
 
-$this->smarty->assign('filepickersize_text', $this->lang('filepickersize'));
-$this->smarty->assign('filepickerwidth_input', 
-	$this->CreateInputText($id, 'filepickerwidth', 
-		$this->GetPreference('filepickerwidth'), 5, 4));
-$this->smarty->assign('filepickerheight_input', 
-	$this->CreateInputText($id, 'filepickerheight', 
-		$this->GetPreference('filepickerheight',''), 5, 4));
+// Content settings
 
-$this->smarty->assign('filepickerheightunit_input', 
-	$this->CreateInputDropdown($id,'filepickerheightunit',array('px'=>'px','%'=>'%','em'=>'em'),0,
-		$this->GetPreference('filepickerheightunit','px')));
+if( $feusers =& $this->GetModuleInstance('FrontEndUsers' )) {
+	
+	$this->smarty->assign('contentsettings_text', $this->lang('contentsettings'));
+	
+	$this->smarty->assign('feuaccess_text', $this->lang('frontendaccess'));
+	$feuAccess = array($this->lang('inherit_from_parent')=>-1);
+	$feuAccess = array_merge($feuAccess,$feusers->GetGroupList());
+	$this->smarty->assign('feuaccess_input', 
+		$this->CreateInputHidden($id,'feu_access','').
+		$this->CreateInputSelectList($id,'feu_access[]',$feuAccess,
+			$this->CleanArray(explode(';',$this->GetPreference('feu_access'))),
+		count($feuAccess),'',1));
+	
+	$this->smarty->assign('redirectpage_text', $this->lang('redirectpage'));
+	$this->smarty->assign('redirectpage_input', 
+		$this->CreateRedirectDropdown($id,'redirect_page',$this->GetPreference('redirect_page')));
+	
+	$this->smarty->assign('redirectparams_text', $this->lang('redirectparams'));
+	$this->smarty->assign('redirectparams_input', 
+		$this->CreateInputText($id, 'redirect_params', 
+			$this->GetPreference('redirect_params'), 32, 128));
+	
+	$this->smarty->assign('evaluatesmarty_text', $this->lang('evaluatesmarty'));
+	$this->smarty->assign('evaluatesmarty_input', 
+		$this->CreateInputHidden($id,'evaluate_smarty',0) .
+		$this->CreateInputCheckbox($id, 'evaluate_smarty', '1', 
+			$this->GetPreference('evaluate_smarty'), 'class="pagecheckbox"'));
+	
+	$this->smarty->assign('feuaction_text', $this->lang('showloginform'));
+	$this->smarty->assign('feuaction_input', 
+		$this->CreateInputDropdown($id,'feu_action',
+			array($this->lang('no')=>'',
+				$this->lang('inherit_from_parent')=>-1,
+				$this->lang('yes')=>1),
+			0,$this->GetPreference('feu_action')));
+}
 
-$this->smarty->assign('filepickerwidthunit_input', 
-	$this->CreateInputDropdown($id,'filepickerwidthunit',array('px'=>'px','%'=>'%','em'=>'em'),0,
-		$this->GetPreference('filepickerwidthunit','px')));
-
-$this->smarty->assign('scalingwidth_text', $this->lang('scalingwidth'));
-$this->smarty->assign('scalingwidth_input', 
-	$this->CreateInputText($id, 'scalingwidth', 
-		$this->GetPreference('scalingwidth'), 5, 4));
-
-$this->smarty->assign('scalingheight_text', $this->lang('scalingheight'));
-$this->smarty->assign('scalingheight_input', 
-	$this->CreateInputText($id, 'scalingheight', 
-		$this->GetPreference('scalingheight'), 5, 4));
-
-$actions = array(lang('none')=>'', 
-	lang('delete')=>1, 
-	$this->lang('setcontent1')=>2, 
-	$this->lang('setcontent2')=>3);
-
-$this->smarty->assign('uninstallaction_input', 
-	$this->CreateInputDropdown($id, 'uninstall_action', $actions, '', 
-		$this->GetPreference('uninstall_action')));
+#---
 
 if(isset($params['message']) && isset($params['submit']))
 	$this->smarty->assign('message', $this->lang($params['message']));
 
 $this->smarty->assign('submit', $this->CreateInputSubmit($id, 'submit', 
 	lang('submit'),'onClick="return submitForm(this,\'\',\'AdvancedContentResult\')"'));
+
 $this->smarty->assign('moduleId', $id);
+
 echo $this->ProcessTemplate('defaultadmin.tpl');
 
 ?>
