@@ -1,34 +1,17 @@
 <?php
-#BEGIN_LICENSE
 #-------------------------------------------------------------------------------
 #
 # Module : AdvancedContent (c) 2010 by Georg Busch (georg.busch@gmx.net)
-# Version: 0.3.4
+#          a content management tool for CMS Made Simple
+#          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
+#          CMS Made Simple is (c) 2004-2010 by Ted Kulp (wishy@cmsmadesimple.org)
+#          The projects homepage is: http://www.cmsmadesimple.org
+# Version: 0.5
 # File   : method.upgrade.php
+# Purpose: performs a module upgrade
+# License: GPL
 #
 #-------------------------------------------------------------------------------
-#
-# CMS - CMS Made Simple is (c) 2004-2010 by Ted Kulp (wishy@cmsmadesimple.org)
-# This project's homepage is: http://www.cmsmadesimple.org
-#
-#-------------------------------------------------------------------------------
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
-#
-#-------------------------------------------------------------------------------
-#END_LICENSE
 
 if (!isset($gCms)) exit;
 
@@ -112,6 +95,24 @@ switch($current_version) {
 		
 		$current_version = '0.3.4';
 		
+	case '0.4':
+		// add new table for user prefs
+		$taboptarray = array('mysql' => 'TYPE=MyISAM');
+		$dict = NewDataDictionary($db);
+		$flds = "user_id I, content_id I, block_id X, message_display I";
+		$sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_AdvancedContent_messagedisplay", 
+			$flds, $taboptarray);
+		$dict->ExecuteSQLArray($sqlarray);
+		
+		$current_version = '0.4.1';
+	
+	case '0.4.1':
+	case '0.4.2':
+	case '0.4.3':
+	case '0.4.4':
+		$this->CreatePermission('Manage AdvancedContent Options', 'Manage AdvancedContent Options');
+		$current_version = '0.5';
+
 	default: 
 		$current_version = $this->GetVersion();
 		break;
